Rename enumerated type to clear a CamelCase warning from checkpatch. The
change is style only. No impact on run time execution.

Signed-off-by: John Whitmore <johnfwhitm...@gmail.com>
---
 drivers/staging/rtl8192u/r819xU_phy.c | 4 ++--
 drivers/staging/rtl8192u/r819xU_phy.h | 4 ++--
 2 files changed, 4 insertions(+), 4 deletions(-)

diff --git a/drivers/staging/rtl8192u/r819xU_phy.h 
b/drivers/staging/rtl8192u/r819xU_phy.h
index a02e1e0ea643..0c63c646b625 100644
--- a/drivers/staging/rtl8192u/r819xU_phy.h
+++ b/drivers/staging/rtl8192u/r819xU_phy.h
@@ -7,7 +7,7 @@
 #define MAX_RFDEPENDCMD_CNT 16
 #define MAX_POSTCMD_CNT 16
 
-enum SwChnlCmdID {
+enum switch_chan_cmd_id {
        CmdID_End,
        CmdID_SetTxPowerLevel,
        CmdID_BBRegWrite10,
@@ -20,7 +20,7 @@ enum SwChnlCmdID {
 /* -----------------------Define structure---------------------- */
 /* 1. Switch channel related */
 struct SwChnlCmd {
-       enum SwChnlCmdID        CmdID;
+       enum switch_chan_cmd_id CmdID;
        u32                     Para1;
        u32                     Para2;
        u32                     msDelay;
diff --git a/drivers/staging/rtl8192u/r819xU_phy.c 
b/drivers/staging/rtl8192u/r819xU_phy.c
index d88f6c3ed46f..c373dbe06154 100644
--- a/drivers/staging/rtl8192u/r819xU_phy.c
+++ b/drivers/staging/rtl8192u/r819xU_phy.c
@@ -1219,7 +1219,7 @@ bool rtl8192_SetRFPowerState(struct net_device *dev,
  * input:     SwChnlCmd      *CmdTable    //table to be set
  *            u32            CmdTableIdx  //variable index in table to be set
  *            u32            CmdTableSz   //table size
  *            SwChnlCmdID    CmdID        //command ID to set
  *            u32            Para1
  *            u32            Para2
  *            u32            msDelay
@@ -1228,7 +1228,7 @@ bool rtl8192_SetRFPowerState(struct net_device *dev,
  * notice:
  
******************************************************************************/
 static u8 rtl8192_phy_SetSwChnlCmdArray(struct SwChnlCmd *CmdTable, u32 
CmdTableIdx,
-                                       u32 CmdTableSz, enum SwChnlCmdID CmdID,
+                                       u32 CmdTableSz, enum switch_chan_cmd_id 
CmdID,
                                        u32 Para1, u32 Para2, u32 msDelay)
 {
@@ -1219,7 +1219,7 @@ bool rtl8192_SetRFPowerState(struct net_device *dev,
  *            u32            CmdTableIdx  //variable index in table to be set
  *            u32            CmdTableSz   //table size
- *            SwChnlCmdID    CmdID        //command ID to set
+ *            switch_chan_cmd_id    CmdID        //command ID to set
  *            u32            Para1
  *            u32            Para2
        struct SwChnlCmd *pCmd;
-- 
2.18.0

_______________________________________________
devel mailing list
de...@linuxdriverproject.org
http://driverdev.linuxdriverproject.org/mailman/listinfo/driverdev-devel

Reply via email to